@@ -6,9 +6,11 @@ use slack_morphism::SlackClient;
 pub mod connector;
 pub mod listener;
 pub mod scroller_ext;
+mod socket_mode;
 
 pub type SlackHyperClient = SlackClient<SlackClientHyperConnector>;
 
 pub use listener::chain_service_routes_fn;
 pub use listener::SlackClientEventsHyperListener;
 pub use scroller_ext::SlackApiResponseScrollerExt;
+pub use socket_mode::*;
